#
# spec file for package qucs-s
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           qucs-s
Version:        1.0.2
Release:        1.4
Summary:        Qucs with SPICE
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Electronics
URL:            https://ra3xdh.github.io/
Source:         https://github.com/ra3xdh/qucs_s/releases/download/%{version}/%{name}-%{version}.tar.gz
Source1:        qucs-s.rpmlintrc
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  cmake(Qt5PrintSupport)
BuildRequires:  cmake(Qt5Svg)
BuildRequires:  cmake(Qt5Xml)
Requires:       ngspice

%description
Qucs-S is a spin-off of the Qucs cross-platform circuit simulator. "S" letter indicates SPICE. The purpose of the Qucs-S subproject is to use free SPICE circuit simulation kernels with the Qucs GUI. It merges the power of SPICE and the simplicity of the Qucs GUI. Qucs intentionally uses its own SPICE incompatible simulation kernel Qucsator. It has advanced RF and AC domain simulation features, but most of the existing industrial SPICE models are incompatible with it. Qucs-S is not a simulator by itself, but it requires to use a simulation backend with it. The schematic document format of Qucs and Qucs-S are fully compatible.

%prep
%setup -q -n %{name}-%{version}

%build
%cmake
%cmake_build

%install
%cmake_install
%fdupes %{buildroot}%{_datadir}/%{name}/

%files
%{_bindir}/*
%{_datadir}/%{name}
%{_datadir}/icons/hicolor/
%{_datadir}/applications/%{name}.desktop
%doc %{_datadir}/man/man1/%{name}.1.gz

%changelog
* Sun May 14 2023 Dirk Müller <dmueller@suse.com>
- update to 1.0.2:
  * Added XSPICE flip-flop digital devices
  * Added INDQ and CAPQ devices representing inductor and
    capacitor with Q-factor
  * Added .LIB directive support
  * Added SPICE entries for I and V file sources
  * Added symbols for 4 and 5 terminal BJT device
  * Added behavioral XSPICE 555 timer model
  * Added option to save SPICE netlist without simulation
  * Improved Qt6 compatibility
  * Improved MacOS compatibility
  * CMake build system update to bring features of the modern
    CMake
* Fri Feb 10 2023 Dirk Müller <dmueller@suse.com>
- update to 1.0.1:
  * Added support for Verilog-A defined devices using
    Ngspice+OpenVAF #197. Old Qucsator+ADMS
    workflow is marked as deprecated. Ngspice >=39 is required
    to support OpenVAF.
  * Implemented variable parameter sweep analysis #189
  * Added possibility to build Qucs-S with Qt6 #190 The
  - DWITH=QT6=ON option for cmake is required.
  * The source code of the Qucs-S is Qt6 compatible now.
  * Simulator prefixes like "ngspice/" are not show anymore on
    plot traces if the plot contains data
    from only one simulator #178
  * Added TL071/TL072 opamp models
  * Added 555_timer.lib library containing the 555 timer model
  * Added extended BJT exteneded and Schottky diodes libraries
  * Change default RCL device values and simulation settings to
    prevent convergence error when putting
    together device with default values #195
  * Fixed auto-scaling issue on Windows 64-bit platform #133
* Sat Nov 26 2022 Dmitry Roshchin <dmitry_r@opensuse.org>
- Initial package, version 1.0.0
